Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3947)

Unified Diff: cc/trees/layer_tree_host_client.h

Issue 348093004: Make cc output surface creation async (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: sievers review Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/trees/layer_tree_host_client.h
diff --git a/cc/trees/layer_tree_host_client.h b/cc/trees/layer_tree_host_client.h
index 74dcbc0cff24631873737c4cdc42341e1051f4ed..326f5c86c41aa6156f0a617cbd214e4a56d38e37 100644
--- a/cc/trees/layer_tree_host_client.h
+++ b/cc/trees/layer_tree_host_client.h
@@ -28,9 +28,11 @@ class LayerTreeHostClient {
virtual void Layout() = 0;
virtual void ApplyScrollAndScale(const gfx::Vector2d& scroll_delta,
float page_scale) = 0;
- // Creates an OutputSurface. If fallback is true, it should attempt to
- // create an OutputSurface that is guaranteed to initialize correctly.
- virtual scoped_ptr<OutputSurface> CreateOutputSurface(bool fallback) = 0;
+ // Request an OutputSurface from the client. When the client has one it should
+ // call LayerTreeHost::SetOutputSurface. If fallback is true, it should
+ // attempt to create an OutputSurface that is guaranteed to initialize
+ // correctly.
+ virtual void RequestNewOutputSurface(bool fallback) = 0;
virtual void DidInitializeOutputSurface() = 0;
virtual void WillCommit() = 0;
virtual void DidCommit() = 0;

Powered by Google App Engine
This is Rietveld 408576698